@@ -33,6 +33,7 @@ from web_foundation.kernel.service import Service
 from web_foundation.resources.database.database import DatabaseResource
 from web_foundation.resources.database.models import AbstractDbModel
 from web_foundation.resources.files.os import OsFilesResource
+from web_foundation.resources.resource import Resource
 from web_foundation.resources.stores.memory_dict import InMemoryDictStore
 from web_foundation.settings_event import SettingsChangeEvent
 from web_foundation.utils.helpers import load_config
@@ -49,8 +50,9 @@ class TicketService(MetricsService):
 class AnyContainer(DependencyContainer):
     database = Dependency(instance_of=DatabaseResource, default=DatabaseResource(modules=[__name__]))
     ticket_service = TicketService()
-    file_repository: Dependency[OsFilesResource] = Dependency(default=OsFilesResource(Path("applied_files")))
-    data_store: Dependency[InMemoryDictStore] = Dependency(default=InMemoryDictStore())
+    file_repository: Dependency[OsFilesResource] = Dependency(instance_of=Resource,
+                                                              default=OsFilesResource(Path("applied_files")))
+    data_store: Dependency[InMemoryDictStore] = Dependency(instance_of=Resource, default=InMemoryDictStore())
 
 
 class TestAddonLoader(AddonsLoader):
