@@ -12,7 +12,7 @@ import loguru
 from loguru import logger
 from web_foundation import settings
 from web_foundation.resources.stores.events import StoreUpdateEvent
-from web_foundation.resources.files.interface import FilesResource
+from web_foundation.resources.files.interface import FilesResourceInterface
 from web_foundation.resources.stores.interface import DataStore
 
 
@@ -95,10 +95,10 @@ class SourceCodeLoader(FileLoader):
 
 class AddonsLoader:
     addons_path: Path
-    files_repo: FilesResource = None
+    files_repo: FilesResourceInterface = None
     store: DataStore = None
 
-    def __init__(self, addons_dir_path: Path, files_repo: FilesResource, store: DataStore):
+    def __init__(self, addons_dir_path: Path, files_repo: FilesResourceInterface, store: DataStore):
         self.addons_path = addons_dir_path
         self.files_repo = files_repo
         self.store = store
