@@ -128,7 +128,7 @@ class App(Generic[GenericDependencyContainer]):
             s_app.ctx.container = self.container
             for service, name in set(in_obj_subclasses(s_app.ctx.container, Service)):
                 service.channel = s_app.ctx.channel
-                service.container = s_app.ctx
+                service.container = s_app.ctx.container
             s_app.ctx.rt_broadcaster = RtBroadcaster()
             for event, resolver, use_nested_classes in self._rt_listeners:
                 s_app.ctx.channel.add_event_listener(
